@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -14,7 +14,10 @@ require_once './libraries/common.inc.php';
  * Runs common work
  */
 $GLOBALS['js_include'][] = 'functions.js';
+$GLOBALS['js_include'][] = 'makegrid.js';
 $GLOBALS['js_include'][] = 'sql.js';
+$GLOBALS['js_include'][] = 'codemirror/lib/codemirror.js';
+$GLOBALS['js_include'][] = 'codemirror/mode/mysql/mysql.js';
 
 require './libraries/db_common.inc.php';
 require_once './libraries/sql_query_form.lib.php';
@@ -31,8 +34,8 @@ $back = 'db_sql.php';
 require './libraries/db_info.inc.php';
 if ($num_tables == 0 && empty($db_query_force)) {
     $sub_part   = '';
-    $is_info    = TRUE;
-    require './db_structure.php';
+    $is_info    = true;
+    include './db_structure.php';
     exit();
 }
 
