@@ -1,17 +1,17 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * @package phpMyAdmin-Engines
+ * @package PhpMyAdmin-Engines
  */
 
 /**
  *
  */
-include_once './libraries/engines/merge.lib.php';
+require_once './libraries/engines/merge.lib.php';
 
 /**
  *
- * @package phpMyAdmin-Engines
+ * @package PhpMyAdmin-Engines
  */
 class PMA_StorageEngine_mrg_myisam extends PMA_StorageEngine_merge
 {
