@@ -5,13 +5,14 @@
  *
  * This includes web server specific code to log some information.
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
  * Logs user information to webserver logs.
  */
-function PMA_log_user($user, $status = 'ok'){
+function PMA_log_user($user, $status = 'ok')
+{
     if (function_exists('apache_note')) {
         apache_note('userID', $user);
         apache_note('userStatus', $status);
