@@ -2,65 +2,12 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-$jscode['master_replication'] = 'divShowHideFunc(\'master_status_href\', \'replication_master_section\');' . "\n"
-    . 'divShowHideFunc(\'master_slaves_href\', \'replication_slaves_section\');' . "\n";
-
-// Add JS events to generate example my.cnf config lines
-$jscode['configure_master'] = 
-    'var c_output = "";' . "\n" .
-    'var c_text = "server-id=' . $serverid . '<br />log-bin=mysql-bin<br />log-error=mysql-bin.err<br />";' . "\n" .
-    'var c_ignore = "binlog_ignore_db=";' . "\n" .
-    'var c_do = "binlog_do_db=";' . "\n" .
-
-    '$(\'db_reset_href\').addEvent(\'click\', function() {' . "\n" .
-    '   $(\'db_select\').getSelected().each(function(el) {' . "\n" .
-    '	  el.selected = false;' . "\n" .
-    '	});' . "\n" .
-    '	$(\'rep\').set(\'html\', c_text);' . "\n" .
-    '});' . "\n" .
-    '$(\'db_type\').addEvent(\'change\',function() {' . "\n" .
-    '	if ($(\'db_type\').getSelected().get(\'value\')=="all")' . "\n" .
-    '	  $(\'rep\').set(\'html\', c_text+c_ignore+c_output);' . "\n" .
-    '	else' . "\n" . 
-    '	  $(\'rep\').set(\'html\', c_text+c_do+c_output);' . "\n" .
-    '});' . "\n" .
-
-    '$(\'db_select\').addEvent(\'change\',function() {' . "\n" .
-    '  var count = 0;' . "\n" .
-
-    '  $(\'db_select\').getSelected().each(function(el) {      ' . "\n" .
-    '	      if (count==0)' . "\n" .
-    '		c_output = el.get(\'value\');' . "\n" .
-    '	      else' . "\n" .
-    '		c_output = c_output + \',\' +el.get(\'value\');' . "\n" .
-
-    '	      count=count+1;' . "\n" .
-
-    '	      if ($(\'db_select\').getSelected().length==count) {' . "\n" .
-    '		if ($(\'db_type\').getSelected().get(\'value\')=="all")' . "\n" .
-    '		  $(\'rep\').set(\'html\', c_text+c_ignore+c_output);' . "\n" .
-    '		else' . "\n" . 
-    '		  $(\'rep\').set(\'html\', c_text+c_do+c_output);' . "\n" .
-    '		count = 0;' . "\n" .
-    '	      }' . "\n" .
-    ' });' . "\n" .
-    '});' . "\n";
-
-$jscode['slave_control'] = 
-    'divShowHideFunc(\'slave_status_href\', \'replication_slave_section\');' . "\n" .
-    'divShowHideFunc(\'slave_control_href\', \'slave_control_gui\');' . "\n" .
-    'divShowHideFunc(\'slave_errormanagement_href\',\'slave_errormanagement_gui\'); ' . "\n";
-
-$jscode['slave_control_sync']  = 
-    'divShowHideFunc(\'slave_synchronization_href\', \'slave_synchronization_gui\');' . "\n";
-
 /**
  * returns code for selecting databases
  *
@@ -72,7 +19,7 @@ function PMA_replication_db_multibox()
     $multi_values .= '<select name="db_select[]" size="6" multiple="multiple" id="db_select">';
 
     foreach ($GLOBALS['pma']->databases as $current_db) {
-        if ('information_schema' == $current_db) {
+        if (PMA_is_system_schema($current_db)) {
             continue;
         }
         if (! empty($selectall) || (isset($tmp_select) && strpos(' ' . $tmp_select, '|' . $current_db . '|'))) {
@@ -85,7 +32,7 @@ function PMA_replication_db_multibox()
     } // end while
 
     $multi_values .= '</select>';
-    $multi_values .= '<br /><a href="#" id="db_reset_href">' . $GLOBALS['strUncheckAll'] . '</a>';
+    $multi_values .= '<br /><a href="#" id="db_reset_href">' . __('Uncheck All') . '</a>';
 
     return $multi_values;
 }
@@ -93,39 +40,40 @@ function PMA_replication_db_multibox()
 /**
  * prints out code for changing master
  *
- * @param String $submitname - submit button name 
+ * @param String $submitname - submit button name
  */
 
-function PMA_replication_gui_changemaster($submitname) {
+function PMA_replication_gui_changemaster($submitname)
+{
 
     list($username_length, $hostname_length) = PMA_replication_get_username_hostname_length();
 
     echo '<form method="post" action="server_replication.php">';
-    echo PMA_generate_common_hidden_inputs('', ''); 
+    echo PMA_generate_common_hidden_inputs('', '');
     echo ' <fieldset id="fieldset_add_user_login">';
-    echo '  <legend>' . $GLOBALS['strReplicationSlaveConfiguration'] . ' - ' . $GLOBALS['strReplicationSlaveChangeMaster'] . '</legend>';
-    echo $GLOBALS['strSlaveConfigure'] . '<br />';
+    echo '  <legend>' . __('Slave configuration') . ' - ' . __('Change or reconfigure master server') . '</legend>';
+    echo __('Make sure, you have unique server-id in your configuration file (my.cnf). If not, please add the following line into [mysqld] section:') . '<br />';
     echo '<pre>server-id=' . time() . '</pre>';
     echo '  <div class="item">';
-    echo '    <label for="text_username">' . $GLOBALS['strUserName'] . ':</label>';
-    echo '    <input type="text" name="username" id="text_username" maxlength="'. $username_length . '" title="' . $GLOBALS['strUserName'] . '" />';
+    echo '    <label for="text_username">' . __('User name') . ':</label>';
+    echo '    <input type="text" name="username" id="text_username" maxlength="'. $username_length . '" title="' . __('User name') . '" />';
     echo '  </div>';
     echo '  <div class="item">';
-    echo '    <label for="text_pma_pw">' . $GLOBALS['strPassword'] .' :</label>';
-    echo '    <input type="password" id="text_pma_pw" name="pma_pw" title="' . $GLOBALS['strPassword'] . '" />';
+    echo '    <label for="text_pma_pw">' . __('Password') .' :</label>';
+    echo '    <input type="password" id="text_pma_pw" name="pma_pw" title="' . __('Password') . '" />';
     echo '  </div>';
     echo '  <div class="item">';
-    echo '    <label for="text_hostname">' . $GLOBALS['strHost'] . ' :</label>';
+    echo '    <label for="text_hostname">' . __('Host') . ' :</label>';
     echo '    <input type="text" id="text_hostname" name="hostname" maxlength="' . $hostname_length . '" value="" />';
     echo '  </div>';
     echo '  <div class="item">';
-    echo '     <label for="text_port">' . $GLOBALS['strPort'] . ':</label>';
+    echo '     <label for="text_port">' . __('Port') . ':</label>';
     echo '     <input type="text" id="text_port" name="port" maxlength="6" value="3306"  />';
     echo '  </div>';
     echo ' </fieldset>';
     echo ' <fieldset id="fieldset_user_privtable_footer" class="tblFooters">';
     echo '    <input type="hidden" name="sr_take_action" value="true" />';
-    echo '     <input type="submit" name="'.$submitname.'" id="confslave_submit" value="' . $GLOBALS['strGo'] . '" />';
+    echo '     <input type="submit" name="' . $submitname . '" id="confslave_submit" value="' . __('Go') . '" />';
     echo ' </fieldset>';
     echo '</form>';
 }
@@ -133,11 +81,12 @@ function PMA_replication_gui_changemaster($submitname) {
 /**
  * This function prints out table with replication status.
  *
- * @param String type - either master or slave
- * @param boolean $hidden - if true, then default style is set to hidden, default value false
- * @param boolen $title - if true, then title is displayed, default true
+ * @param string  $type   either master or slave
+ * @param boolean $hidden if true, then default style is set to hidden, default value false
+ * @param boolen  $title  if true, then title is displayed, default true
  */
-function PMA_replication_print_status_table($type, $hidden = false, $title = true) {
+function PMA_replication_print_status_table($type, $hidden = false, $title = true)
+{
     global ${"{$type}_variables"};
     global ${"{$type}_variables_alerts"};
     global ${"{$type}_variables_oks"};
@@ -151,10 +100,14 @@ function PMA_replication_print_status_table($type, $hidden = false, $title = tru
     //
     //$server_id = PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'server_id'", 0, 1);
 
-    echo '<div id="replication_' . $type . '_section" style="' . ($hidden ? 'display: none' : '') . '"> ';
+    echo '<div id="replication_' . $type . '_section" style="' . ($hidden ? 'display: none;' : '') . '"> ';
 
     if ($title) {
-        echo '<h4><a name="replication_' . $type . '"></a>' . ${"strReplicationStatus_{$type}"} . '</h4>';
+        if ($type == 'master') {
+            echo '<h4><a name="replication_' . $type . '"></a>' . __('Master status') . '</h4>';
+        } else {
+            echo '<h4><a name="replication_' . $type . '"></a>' . __('Slave status') . '</h4>';
+        }
     } else {
         echo '<br />';
     }
@@ -162,8 +115,8 @@ function PMA_replication_print_status_table($type, $hidden = false, $title = tru
     echo '   <table id="server' . $type . 'replicationsummary" class="data"> ';
     echo '   <thead>';
     echo '    <tr>';
-    echo ' 	<th>' . $GLOBALS['strVar'] . '</th>';
-    echo '		<th>' . $GLOBALS['strValue'] . '</th>';
+    echo '     <th>' . __('Variable') . '</th>';
+    echo '        <th>' . __('Value') . '</th>';
     echo '    </tr>';
     echo '   </thead>';
     echo '   <tbody>';
@@ -178,19 +131,19 @@ function PMA_replication_print_status_table($type, $hidden = false, $title = tru
 
 
         // TODO change to regexp or something, to allow for negative match
-        if (isset(${"{$type}_variables_alerts"}[$variable]) 
+        if (isset(${"{$type}_variables_alerts"}[$variable])
             && ${"{$type}_variables_alerts"}[$variable] == ${"server_{$type}_replication"}[0][$variable]
         ) {
             echo '<span class="attention">';
 
-        } elseif (isset(${"{$type}_variables_oks"}[$variable]) 
+        } elseif (isset(${"{$type}_variables_oks"}[$variable])
             && ${"{$type}_variables_oks"}[$variable] == ${"server_{$type}_replication"}[0][$variable]
         ) {
             echo '<span class="allfine">';
         } else {
             echo '<span>';
         }
-        echo ${"server_{$type}_replication"}[0][$variable]; 
+        echo ${"server_{$type}_replication"}[0][$variable];
         echo '</span>';
 
         echo '  </td>';
@@ -211,18 +164,19 @@ function PMA_replication_print_status_table($type, $hidden = false, $title = tru
  *
  * @param boolean $hidden - if true, then default style is set to hidden, default value false
  */
-function PMA_replication_print_slaves_table($hidden = false) {
+function PMA_replication_print_slaves_table($hidden = false)
+{
 
     // Fetch data
-    $data = PMA_DBI_fetch_result('SHOW SLAVE HOSTS', null, null); 
+    $data = PMA_DBI_fetch_result('SHOW SLAVE HOSTS', null, null);
 
     echo '  <br />';
-    echo '  <div id="replication_slaves_section" style="' . ($hidden ? 'display: none' : '') . '"> ';
+    echo '  <div id="replication_slaves_section" style="' . ($hidden ? 'display: none;' : '') . '"> ';
     echo '    <table class="data">';
     echo '    <thead>';
     echo '      <tr>';
-    echo '        <th>' . $GLOBALS['strBinLogServerId'] . '</th>';
-    echo '        <th>' . $GLOBALS['strHost'] . '</th>';
+    echo '        <th>' . __('Server ID') . '</th>';
+    echo '        <th>' . __('Host') . '</th>';
     echo '      </tr>';
     echo '    </thead>';
     echo '    <tbody>';
@@ -240,7 +194,7 @@ function PMA_replication_print_slaves_table($hidden = false) {
     echo '    </tbody>';
     echo '    </table>';
     echo '    <br />';
-    PMA_Message::notice('strReplicationShowConnectedSlavesNote')->display();
+    PMA_Message::notice(__('Only slaves started with the --report-host=host_name option are visible in this list.'))->display();
     echo '    <br />';
     echo '  </div>';
 }
@@ -248,15 +202,15 @@ function PMA_replication_print_slaves_table($hidden = false) {
 /**
  * get the correct username and hostname lengths for this MySQL server
  *
- * @uses    strtok()
  * @return  array   username length, hostname length
  */
 
-function PMA_replication_get_username_hostname_length() {
-    $fields_info = PMA_DBI_get_fields('mysql', 'user');
+function PMA_replication_get_username_hostname_length()
+{
+    $fields_info = PMA_DBI_get_columns('mysql', 'user');
     $username_length = 16;
     $hostname_length = 41;
-    foreach ($fields_info as $key => $val) {
+    foreach ($fields_info as $val) {
         if ($val['Field'] == 'User') {
             strtok($val['Type'], '()');
             $v = strtok('()');
@@ -277,7 +231,8 @@ function PMA_replication_get_username_hostname_length() {
 /**
  * Print code to add a replication slave user to the master
  */
-function PMA_replication_gui_master_addslaveuser() {
+function PMA_replication_gui_master_addslaveuser()
+{
 
     list($username_length, $hostname_length) = PMA_replication_get_username_hostname_length();
 
@@ -288,26 +243,26 @@ function PMA_replication_gui_master_addslaveuser() {
     echo '<form autocomplete="off" method="post" action="server_privileges.php" onsubmit="return checkAddUser(this);">';
     echo PMA_generate_common_hidden_inputs('', '');
     echo '<fieldset id="fieldset_add_user_login">'
-        . '<legend>'.$GLOBALS['strReplicationAddSlaveUser'].'</legend>'
-	. '<input type="hidden" name="grant_count" value="25" />'
-	. '<input type="hidden" name="createdb" id="createdb_0" value="0" />'
+        . '<legend>'.__('Add slave replication user').'</legend>'
+    . '<input type="hidden" name="grant_count" value="25" />'
+    . '<input type="hidden" name="createdb" id="createdb_0" value="0" />'
         . '<input id="checkbox_Repl_slave_priv" type="hidden" title="Needed for the replication slaves." value="Y" name="Repl_slave_priv"/>'
         . '<input id="checkbox_Repl_client_priv" type="hidden" title="Needed for the replication slaves." value="Y" name="Repl_client_priv"/>'
-	. ''
+    . ''
         . '<input type="hidden" name="sr_take_action" value="true" />'
         . '<div class="item">'
         . '<label for="select_pred_username">'
-        . '    ' . $GLOBALS['strUserName'] . ':'
+        . '    ' . __('User name') . ':'
         . '</label>'
         . '<span class="options">'
-        . '    <select name="pred_username" id="select_pred_username" title="' . $GLOBALS['strUserName'] . '"'
+        . '    <select name="pred_username" id="select_pred_username" title="' . __('User name') . '"'
         . '        onchange="if (this.value == \'any\') { username.value = \'\'; } else if (this.value == \'userdefined\') { username.focus(); username.select(); }">'
-        . '        <option value="any"' . ((isset($GLOBALS['pred_username']) && $GLOBALS['pred_username'] == 'any') ? ' selected="selected"' : '') . '>' . $GLOBALS['strAnyUser'] . '</option>'
-        . '        <option value="userdefined"' . ((! isset($GLOBALS['pred_username']) || $GLOBALS['pred_username'] == 'userdefined') ? ' selected="selected"' : '') . '>' . $GLOBALS['strUseTextField'] . ':</option>'
+        . '        <option value="any"' . ((isset($GLOBALS['pred_username']) && $GLOBALS['pred_username'] == 'any') ? ' selected="selected"' : '') . '>' . __('Any user') . '</option>'
+        . '        <option value="userdefined"' . ((! isset($GLOBALS['pred_username']) || $GLOBALS['pred_username'] == 'userdefined') ? ' selected="selected"' : '') . '>' . __('Use text field') . ':</option>'
         . '    </select>'
         . '</span>'
         . '<input type="text" name="username" maxlength="'
-        . $username_length . '" title="' . $GLOBALS['strUserName'] . '"'
+        . $username_length . '" title="' . __('User name') . '"'
         . (empty($GLOBALS['username'])
         ? ''
         : ' value="' . (isset($GLOBALS['new_username'])
@@ -317,10 +272,10 @@ function PMA_replication_gui_master_addslaveuser() {
         . '</div>'
         . '<div class="item">'
         . '<label for="select_pred_hostname">'
-        . '    ' . $GLOBALS['strHost'] . ':'
+        . '    ' . __('Host') . ':'
         . '</label>'
         . '<span class="options">'
-        . '    <select name="pred_hostname" id="select_pred_hostname" title="' . $GLOBALS['strHost'] . '"';
+        . '    <select name="pred_hostname" id="select_pred_hostname" title="' . __('Host') . '"';
     $_current_user = PMA_DBI_fetch_value('SELECT USER();');
     if (! empty($_current_user)) {
         $thishost = str_replace("'", '', substr($_current_user, (strrpos($_current_user, '@') + 1)));
@@ -350,73 +305,74 @@ function PMA_replication_gui_master_addslaveuser() {
     }
     echo '        <option value="any"'
         . ((isset($GLOBALS['pred_hostname']) && $GLOBALS['pred_hostname'] == 'any')
-        ? ' selected="selected"' : '') . '>' . $GLOBALS['strAnyHost']
+        ? ' selected="selected"' : '') . '>' . __('Any host')
         . '</option>'
         . '        <option value="localhost"'
         . ((isset($GLOBALS['pred_hostname']) && $GLOBALS['pred_hostname'] == 'localhost')
-        ? ' selected="selected"' : '') . '>' . $GLOBALS['strLocalhost']
+        ? ' selected="selected"' : '') . '>' . __('Local')
         . '</option>';
+
     if (!empty($thishost)) {
         echo '        <option value="thishost"'
             . ((isset($GLOBALS['pred_hostname']) && $GLOBALS['pred_hostname'] == 'thishost')
-            ? ' selected="selected"' : '') . '>' . $GLOBALS['strThisHost']
+            ? ' selected="selected"' : '') . '>' . __('This Host')
             . '</option>';
     }
     unset($thishost);
     echo '        <option value="hosttable"'
         . ((isset($GLOBALS['pred_hostname']) && $GLOBALS['pred_hostname'] == 'hosttable')
-        ? ' selected="selected"' : '') . '>' . $GLOBALS['strUseHostTable']
+        ? ' selected="selected"' : '') . '>' . __('Use Host Table')
         . '</option>'
         . '        <option value="userdefined"'
         . ((isset($GLOBALS['pred_hostname']) && $GLOBALS['pred_hostname'] == 'userdefined')
         ? ' selected="selected"' : '')
-        . '>' . $GLOBALS['strUseTextField'] . ':</option>'
+        . '>' . __('Use text field') . ':</option>'
         . '    </select>'
         . '</span>'
         . '<input type="text" name="hostname" maxlength="'
         . $hostname_length . '" value="'
         . (isset($GLOBALS['hostname']) ? $GLOBALS['hostname'] : '')
-        . '" title="' . $GLOBALS['strHost']
+        . '" title="' . __('Host')
         . '" onchange="pred_hostname.value = \'userdefined\';" />'
-        . PMA_showHint($GLOBALS['strHostTableExplanation'])
+        . PMA_showHint(__('When Host table is used, this field is ignored and values stored in Host table are used instead.'))
         . '</div>'
         . '<div class="item">'
         . '<label for="select_pred_password">'
-        . '    ' . $GLOBALS['strPassword'] . ':'
+        . '    ' . __('Password') . ':'
         . '</label>'
         . '<span class="options">'
         . '    <select name="pred_password" id="select_pred_password" title="'
-        . $GLOBALS['strPassword'] . '"'
+        . __('Password') . '"'
         . '            onchange="if (this.value == \'none\') { pma_pw.value = \'\'; pma_pw2.value = \'\'; } else if (this.value == \'userdefined\') { pma_pw.focus(); pma_pw.select(); }">'
         . '        <option value="none"';
     if (isset($GLOBALS['username']) && $mode != 'change') {
         echo '  selected="selected"';
     }
-    echo '>' . $GLOBALS['strNoPassword'] . '</option>'
-        . '        <option value="userdefined"' . (isset($GLOBALS['username']) ? '' : ' selected="selected"') . '>' . $GLOBALS['strUseTextField'] . ':</option>'
+    echo '>' . __('No Password') . '</option>'
+        . '        <option value="userdefined"' . (isset($GLOBALS['username']) ? '' : ' selected="selected"') . '>' . __('Use text field') . ':</option>'
         . '    </select>'
         . '</span>'
-        . '<input type="password" id="text_pma_pw" name="pma_pw" title="' . $GLOBALS['strPassword'] . '" onchange="pred_password.value = \'userdefined\';" />'
+        . '<input type="password" id="text_pma_pw" name="pma_pw" title="' . __('Password') . '" onchange="pred_password.value = \'userdefined\';" />'
         . '</div>'
         . '<div class="item">'
         . '<label for="text_pma_pw2">'
-        . '    ' . $GLOBALS['strReType'] . ':'
+        . '    ' . __('Re-type') . ':'
         . '</label>'
         . '<span class="options">&nbsp;</span>'
-        . '<input type="password" name="pma_pw2" id="text_pma_pw2" title="' . $GLOBALS['strReType'] . '" onchange="pred_password.value = \'userdefined\';" />'
+        . '<input type="password" name="pma_pw2" id="text_pma_pw2" title="' . __('Re-type') . '" onchange="pred_password.value = \'userdefined\';" />'
         . '</div>'
         . '<div class="item">'
         . '<label for="button_generate_password">'
-        . '    ' . $GLOBALS['strGeneratePassword'] . ':'
+        . '    ' . __('Generate Password') . ':'
         . '</label>'
         . '<span class="options">'
-        . '    <input type="button" id="button_generate_password" value="' . $GLOBALS['strGenerate'] . '" onclick="suggestPassword(this.form)" />'
+        . '    <input type="button" id="button_generate_password" value="' . __('Generate') . '" onclick="suggestPassword(this.form)" />'
         . '</span>'
         . '<input type="text" name="generated_pw" id="generated_pw" />'
         . '</div>'
         . '</fieldset>';
     echo '<fieldset id="fieldset_user_privtable_footer" class="tblFooters">'
-        . '    <input type="submit" name="adduser_submit" id="adduser_submit" value="' . $GLOBALS['strGo'] . '" />'
+        . '    <input type="submit" name="adduser_submit" id="adduser_submit" value="' . __('Go') . '" />'
         . '</fieldset>';
     echo '</form>';
     echo '</div>';
