@@ -2,8 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -18,7 +17,7 @@ require './libraries/tbl_common.php';
  */
 $print_view = true;
 if (! isset($selected_tbl)) {
-    require_once './libraries/header.inc.php';
+    include_once './libraries/header.inc.php';
 }
 
 // Check parameters
@@ -30,7 +29,6 @@ if (! isset($the_tables) || ! is_array($the_tables)) {
 /**
  * Gets the relations settings
  */
-require_once './libraries/relation.lib.php';
 require_once './libraries/transformations.lib.php';
 require_once './libraries/Index.class.php';
 
@@ -53,8 +51,7 @@ PMA_DBI_select_db($db);
 
 
 /**
- * Multi-tables printview thanks to Christophe Gesche from the "MySQL Form
- * Generator for PHPMyAdmin" (http://sourceforge.net/projects/phpmysqlformgen/)
+ * Multi-tables printview
  */
 if (isset($selected_tbl) && is_array($selected_tbl)) {
     $the_tables   = $selected_tbl;
@@ -65,14 +62,14 @@ $multi_tables     = (count($the_tables) > 1);
 
 if ($multi_tables) {
     if (empty($GLOBALS['is_header_sent'])) {
-        require_once './libraries/header.inc.php';
+        include_once './libraries/header.inc.php';
     }
     $tbl_list     = '';
     foreach ($the_tables as $key => $table) {
         $tbl_list .= (empty($tbl_list) ? '' : ', ')
                   . PMA_backquote($table);
     }
-    echo '<strong>'.  $strShowTables . ': ' . $tbl_list . '</strong>' . "\n";
+    echo '<strong>'.  __('Showing tables') . ': ' . htmlspecialchars($tbl_list) . '</strong>' . "\n";
     echo '<hr />' . "\n";
 } // end if
 
@@ -87,7 +84,7 @@ foreach ($the_tables as $key => $table) {
     }
     $counter++;
     echo '<div' . $breakstyle . '>' . "\n";
-    echo '<h1>' . $table . '</h1>' . "\n";
+    echo '<h1>' . htmlspecialchars($table) . '</h1>' . "\n";
 
     /**
      * Gets table informations
@@ -101,23 +98,20 @@ foreach ($the_tables as $key => $table) {
     /**
      * Gets fields properties
      */
-    $result      = PMA_DBI_query(
-        'SHOW FIELDS FROM ' . PMA_backquote($table) . ';', null,
-        PMA_DBI_QUERY_STORE);
-    $fields_cnt  = PMA_DBI_num_rows($result);
+    $columns = PMA_DBI_get_columns($db, $table);
 
 
-// We need this to correctly learn if a TIMESTAMP is NOT NULL, since
-// SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
-// and SHOW CREATE TABLE says NOT NULL (tested
-// in MySQL 4.0.25 and 5.0.21, http://bugs.mysql.com/20910).
+    // We need this to correctly learn if a TIMESTAMP is NOT NULL, since
+    // SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
+    // and SHOW CREATE TABLE says NOT NULL (tested
+    // in MySQL 4.0.25 and 5.0.21, http://bugs.mysql.com/20910).
 
     $show_create_table = PMA_DBI_fetch_value(
         'SHOW CREATE TABLE ' . PMA_backquote($db) . '.' . PMA_backquote($table),
         0, 1);
     $analyzed_sql = PMA_SQP_analyze(PMA_SQP_parse($show_create_table));
 
-    // Check if we can use Relations (Mike Beck)
+    // Check if we can use Relations
     // Find which tables are related with the current one and write it in
     // an array
     $res_rel  = PMA_getForeigners($db, $table);
@@ -127,7 +121,7 @@ foreach ($the_tables as $key => $table) {
      * Displays the comments of the table if MySQL >= 3.23
      */
     if (!empty($show_comment)) {
-        echo $strTableComments . ': ' . htmlspecialchars($show_comment) . '<br /><br />';
+        echo __('Table comments') . ': ' . htmlspecialchars($show_comment) . '<br /><br />';
     }
 
     /**
@@ -139,17 +133,15 @@ foreach ($the_tables as $key => $table) {
 <table style="width: 100%;">
 <thead>
 <tr>
-    <th><?php echo $strField; ?></th>
-    <th><?php echo $strType; ?></th>
-    <!--<th><?php echo $strAttr; ?></th>-->
-    <th><?php echo $strNull; ?></th>
-    <th><?php echo $strDefault; ?></th>
-    <!--<th><?php echo $strExtra; ?></th>-->
+    <th><?php echo __('Column'); ?></th>
+    <th><?php echo __('Type'); ?></th>
+    <th><?php echo __('Null'); ?></th>
+    <th><?php echo __('Default'); ?></th>
     <?php
     if ($have_rel) {
-        echo '<th>' . $strLinksTo . '</th>' . "\n";
+        echo '<th>' . __('Links to') . '</th>' . "\n";
     }
-    echo '    <th>' . $strComments . '</th>' . "\n";
+    echo '    <th>' . __('Comments') . '</th>' . "\n";
     if ($cfgRelation['mimework']) {
         echo '    <th>MIME</th>' . "\n";
     }
@@ -158,41 +150,12 @@ foreach ($the_tables as $key => $table) {
 </thead>
 <tbody>
     <?php
-    while ($row = PMA_DBI_fetch_assoc($result)) {
-        $type             = $row['Type'];
-        // reformat mysql query output - staybyte - 9. June 2001
-        // loic1: set or enum types: slashes single quotes inside options
-        if (preg_match('@^(set|enum)\((.+)\)$@i', $type, $tmp)) {
-            $tmp[2]       = substr(preg_replace('@([^,])\'\'@', '\\1\\\'',
-                                    ',' . $tmp[2]), 1);
-            $type         = $tmp[1] . '(' . str_replace(',', ', ', $tmp[2]) . ')';
+    foreach ($columns as $row) {
+        $extracted_fieldspec = PMA_extractFieldSpec($row['Type']);
+        $type             = $extracted_fieldspec['print_type'];
+        $attribute     = $extracted_fieldspec['attribute'];
 
-            $binary       = 0;
-            $unsigned     = 0;
-            $zerofill     = 0;
-        } else {
-            $type         = preg_replace('@BINARY@i', '', $type);
-            $type         = preg_replace('@ZEROFILL@i', '', $type);
-            $type         = preg_replace('@UNSIGNED@i', '', $type);
-            if (empty($type)) {
-                $type     = '&nbsp;';
-            }
-
-            $binary       = stristr($row['Type'], 'binary');
-            $unsigned     = stristr($row['Type'], 'unsigned');
-            $zerofill     = stristr($row['Type'], 'zerofill');
-        }
-        $strAttribute     = '&nbsp;';
-        if ($binary) {
-            $strAttribute = 'BINARY';
-        }
-        if ($unsigned) {
-            $strAttribute = 'UNSIGNED';
-        }
-        if ($zerofill) {
-            $strAttribute = 'UNSIGNED ZEROFILL';
-        }
-        if (!isset($row['Default'])) {
+        if (! isset($row['Default'])) {
             if ($row['Null'] != ''  && $row['Null'] != 'NO') {
                 $row['Default'] = '<i>NULL</i>';
             }
@@ -201,7 +164,7 @@ foreach ($the_tables as $key => $table) {
         }
         $field_name = htmlspecialchars($row['Field']);
 
-        // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
+        // here, we have a TIMESTAMP that SHOW FULL COLUMNS reports as having the
         // NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
         // the latter.
         /**
@@ -213,55 +176,51 @@ foreach ($the_tables as $key => $table) {
         if (!empty($analyzed_sql[0]['create_table_fields'][$field_name]['type']) && $analyzed_sql[0]['create_table_fields'][$field_name]['type'] == 'TIMESTAMP' && $analyzed_sql[0]['create_table_fields'][$field_name]['timestamp_not_null']) {
             $row['Null'] = '';
         }
-        ?>
 
-<tr><td>
-    <?php
-    if (isset($pk_array[$row['Field']])) {
-        echo '    <u>' . $field_name . '</u>' . "\n";
-    } else {
-        echo '    ' . $field_name . "\n";
-    }
+        echo '<tr><td>';
+
+        if (isset($pk_array[$row['Field']])) {
+            echo '    <u>' . $field_name . '</u>' . "\n";
+        } else {
+            echo '    ' . $field_name . "\n";
+        }
     ?>
     </td>
     <td><?php echo $type; ?><bdo dir="ltr"></bdo></td>
-    <!--<td><?php echo $strAttribute; ?></td>-->
-    <td><?php echo (($row['Null'] == '' || $row['Null'] == 'NO') ? $strNo : $strYes); ?>&nbsp;</td>
+    <td><?php echo (($row['Null'] == '' || $row['Null'] == 'NO') ? __('No') : __('Yes')); ?>&nbsp;</td>
     <td><?php if (isset($row['Default'])) { echo $row['Default']; } ?>&nbsp;</td>
-    <!--<td><?php echo $row['Extra']; ?>&nbsp;</td>-->
     <?php
-    if ($have_rel) {
+        if ($have_rel) {
+            echo '    <td>';
+            if (isset($res_rel[$field_name])) {
+                echo htmlspecialchars($res_rel[$field_name]['foreign_table'] . ' -> ' . $res_rel[$field_name]['foreign_field']);
+            }
+            echo '&nbsp;</td>' . "\n";
+        }
         echo '    <td>';
-        if (isset($res_rel[$field_name])) {
-            echo htmlspecialchars($res_rel[$field_name]['foreign_table'] . ' -> ' . $res_rel[$field_name]['foreign_field']);
+        $comments = PMA_getComments($db, $table);
+        if (isset($comments[$field_name])) {
+            echo htmlspecialchars($comments[$field_name]);
         }
         echo '&nbsp;</td>' . "\n";
-    }
-    echo '    <td>';
-    $comments = PMA_getComments($db, $table);
-    if (isset($comments[$field_name])) {
-        echo htmlspecialchars($comments[$field_name]);
-    }
-    echo '&nbsp;</td>' . "\n";
-    if ($cfgRelation['mimework']) {
-        $mime_map = PMA_getMIME($db, $table, true);
+        if ($cfgRelation['mimework']) {
+            $mime_map = PMA_getMIME($db, $table, true);
 
-        echo '    <td>';
-        if (isset($mime_map[$field_name])) {
-            echo htmlspecialchars(str_replace('_', '/', $mime_map[$field_name]['mimetype']));
+            echo '    <td>';
+            if (isset($mime_map[$field_name])) {
+                echo htmlspecialchars(str_replace('_', '/', $mime_map[$field_name]['mimetype']));
+            }
+            echo '&nbsp;</td>' . "\n";
         }
-        echo '&nbsp;</td>' . "\n";
-    }
     ?>
 </tr>
         <?php
-    } // end while
-    PMA_DBI_free_result($result);
+    } // end foreach
     ?>
 </tbody>
 </table>
     <?php
-    if (! $tbl_is_view && $db != 'information_schema') {
+    if (! $tbl_is_view && !PMA_is_system_schema($db)) {
         /**
          * Displays indexes
          */
@@ -270,7 +229,6 @@ foreach ($the_tables as $key => $table) {
         /**
          * Displays Space usage and row statistics
          *
-         * staybyte - 9 June 2001
          */
         if ($cfg['ShowStats']) {
             $nonisam     = false;
@@ -280,7 +238,7 @@ foreach ($the_tables as $key => $table) {
             if ($nonisam == false) {
                 // Gets some sizes
 
-		$mergetable = PMA_Table::isMerge($db, $table);
+                $mergetable = PMA_Table::isMerge($db, $table);
 
                 list($data_size, $data_unit)         = PMA_formatByteDown($showtable['Data_length']);
                 if ($mergetable == false) {
@@ -308,14 +266,10 @@ foreach ($the_tables as $key => $table) {
 
         <!-- Space usage -->
         <td valign="top">
-            <big><?php echo $strSpaceUsage . ':'; ?></big>
+            <big><?php echo __('Space usage') . ':'; ?></big>
             <table width="100%">
             <tr>
-                <th><?php echo $strType; ?></th>
-                <th colspan="2" align="center"><?php echo $strUsage; ?></th>
-            </tr>
-            <tr>
-                <td style="padding-right: 10px"><?php echo $strData; ?></td>
+                <td style="padding-right: 10px"><?php echo __('Data'); ?></td>
                 <td align="right"><?php echo $data_size; ?></td>
                 <td><?php echo $data_unit; ?></td>
             </tr>
@@ -324,7 +278,7 @@ foreach ($the_tables as $key => $table) {
                     echo "\n";
                     ?>
             <tr>
-                <td style="padding-right: 10px"><?php echo $strIndex; ?></td>
+                <td style="padding-right: 10px"><?php echo __('Index'); ?></td>
                 <td align="right"><?php echo $index_size; ?></td>
                 <td><?php echo $index_unit; ?></td>
             </tr>
@@ -334,12 +288,12 @@ foreach ($the_tables as $key => $table) {
                     echo "\n";
                     ?>
             <tr style="color: #bb0000">
-                <td style="padding-right: 10px"><?php echo $strOverhead; ?></td>
+                <td style="padding-right: 10px"><?php echo __('Overhead'); ?></td>
                 <td align="right"><?php echo $free_size; ?></td>
                 <td><?php echo $free_unit; ?></td>
             </tr>
             <tr>
-                <td style="padding-right: 10px"><?php echo $strEffective; ?></td>
+                <td style="padding-right: 10px"><?php echo __('Effective'); ?></td>
                 <td align="right"><?php echo $effect_size; ?></td>
                 <td><?php echo $effect_unit; ?></td>
             </tr>
@@ -349,7 +303,7 @@ foreach ($the_tables as $key => $table) {
                     echo "\n";
                     ?>
             <tr>
-                <td style="padding-right: 10px"><?php echo $strTotalUC; ?></td>
+                <td style="padding-right: 10px"><?php echo __('Total'); ?></td>
                 <td align="right"><?php echo $tot_size; ?></td>
                 <td><?php echo $tot_unit; ?></td>
             </tr>
@@ -364,23 +318,19 @@ foreach ($the_tables as $key => $table) {
 
         <!-- Rows Statistic -->
         <td valign="top">
-            <big><?php echo $strRowsStatistic . ':'; ?></big>
+            <big><?php echo __('Row Statistics') . ':'; ?></big>
             <table width="100%">
-            <tr>
-                <th><?php echo $strStatement; ?></th>
-                <th align="center"><?php echo $strValue; ?></th>
-            </tr>
                 <?php
                 if (isset($showtable['Row_format'])) {
                     ?>
             <tr>
-                <td><?php echo ucfirst($strFormat); ?></td>
+                <td><?php echo __('Format'); ?></td>
                 <td align="<?php echo $cell_align_left; ?>">
                     <?php
                     if ($showtable['Row_format'] == 'Fixed') {
-                        echo $strStatic;
+                        echo __('static');
                     } elseif ($showtable['Row_format'] == 'Dynamic') {
-                        echo $strDynamic;
+                        echo __('dynamic');
                     } else {
                         echo $showtable['Row_format'];
                     }
@@ -392,7 +342,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Rows'])) {
                     ?>
             <tr>
-                <td><?php echo ucfirst($strRows); ?></td>
+                <td><?php echo __('Rows'); ?></td>
                 <td align="right">
                     <?php echo PMA_formatNumber($showtable['Rows'], 0) . "\n"; ?>
                 </td>
@@ -402,7 +352,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Avg_row_length']) && $showtable['Avg_row_length'] > 0) {
                     ?>
             <tr>
-                <td><?php echo ucfirst($strRowLength); ?>&nbsp;&oslash;</td>
+                <td><?php echo __('Row length'); ?>&nbsp;&oslash;</td>
                 <td>
                     <?php echo PMA_formatNumber($showtable['Avg_row_length'], 0) . "\n"; ?>
                 </td>
@@ -412,7 +362,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Data_length']) && $showtable['Rows'] > 0 && $mergetable == false) {
                     ?>
             <tr>
-                <td><?php echo ucfirst($strRowSize); ?>&nbsp;&oslash;</td>
+                <td><?php echo __('Row size'); ?>&nbsp;&oslash;</td>
                 <td align="right">
                     <?php echo $avg_size . ' ' . $avg_unit . "\n"; ?>
                 </td>
@@ -422,7 +372,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Auto_increment'])) {
                     ?>
             <tr>
-                <td><?php echo ucfirst($strNext); ?>&nbsp;Autoindex</td>
+                <td><?php echo __('Next autoindex'); ?></td>
                 <td align="right">
                     <?php echo PMA_formatNumber($showtable['Auto_increment'], 0) . "\n"; ?>
                 </td>
@@ -432,7 +382,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Create_time'])) {
                     ?>
             <tr>
-                <td><?php echo $strStatCreateTime; ?></td>
+                <td><?php echo __('Creation'); ?></td>
                 <td align="right">
                     <?php echo PMA_localisedDate(strtotime($showtable['Create_time'])) . "\n"; ?>
                 </td>
@@ -442,7 +392,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Update_time'])) {
                     ?>
             <tr>
-                <td><?php echo $strStatUpdateTime; ?></td>
+                <td><?php echo __('Last update'); ?></td>
                 <td align="right">
                     <?php echo PMA_localisedDate(strtotime($showtable['Update_time'])) . "\n"; ?>
                 </td>
@@ -452,7 +402,7 @@ foreach ($the_tables as $key => $table) {
                 if (isset($showtable['Check_time'])) {
                     ?>
             <tr>
-                <td><?php echo $strStatCheckTime; ?></td>
+                <td><?php echo __('Last check'); ?></td>
                 <td align="right">
                     <?php echo PMA_localisedDate(strtotime($showtable['Check_time'])) . "\n"; ?>
                 </td>
@@ -481,24 +431,9 @@ foreach ($the_tables as $key => $table) {
 /**
  * Displays the footer
  */
-?>
+PMA_printButton();
 
-<script type="text/javascript">
-//<![CDATA[
-function printPage()
-{
-    // Do print the page
-    if (typeof(window.print) != 'undefined') {
-        window.print();
-    }
-}
-//]]>
-</script>
+echo "<div id='PMA_disable_floating_menubar'></div>\n";
 
-<p class="print_ignore">
-    <input type="button" id="print" value="<?php echo $strPrint; ?>"
-        onclick="printPage()" /></p>
-
-<?php
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
 ?>
