@@ -3,7 +3,7 @@
 /**
  * Displays table structure infos like fields/columns, indexes, size, rows
  * and allows manipulation of indexes and columns/fields
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -12,9 +12,9 @@
 require_once './libraries/common.inc.php';
 require_once './libraries/mysql_charsets.lib.php';
 
-$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.16.custom.js';
 $GLOBALS['js_include'][] = 'tbl_structure.js';
-
+$GLOBALS['js_include'][] = 'indexes.js';
 /**
  * handle multiple field commands if required
  *
@@ -30,6 +30,8 @@ if (isset($_REQUEST['submit_mult_change_x'])) {
     $submit_mult = 'index';
 } elseif (isset($_REQUEST['submit_mult_unique_x'])) {
     $submit_mult = 'unique';
+} elseif (isset($_REQUEST['submit_mult_spatial_x'])) {
+    $submit_mult = 'spatial';
 } elseif (isset($_REQUEST['submit_mult_fulltext_x'])) {
     $submit_mult = 'ftext';
 } elseif (isset($_REQUEST['submit_mult_browse_x'])) {
@@ -60,13 +62,13 @@ if (! empty($submit_mult) && isset($_REQUEST['selected_fld'])) {
         // what is this htmlspecialchars() for??
         //$sql_query .= ' FROM ' . PMA_backquote(htmlspecialchars($table));
         $sql_query .= ' FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table);
-        require './sql.php';
+        include './sql.php';
         exit;
     } else {
         // handle multiple field commands
         // handle confirmation of deleting multiple fields/columns
         $action = 'tbl_structure.php';
-        require './libraries/mult_submits.inc.php';
+        include './libraries/mult_submits.inc.php';
         //require_once './libraries/header.inc.php';
         //require_once './libraries/tbl_links.inc.php';
 
@@ -121,19 +123,16 @@ foreach (PMA_Index::getFromTable($table, $db) as $index) {
 unset($index, $columns, $column_name, $dummy);
 
 // 3. Get fields
-$fields_rs   = PMA_DRIZZLE
-			? PMA_DBI_query('SHOW COLUMNS FROM ' . PMA_backquote($table) . ';', null, PMA_DBI_QUERY_STORE)
-			: PMA_DBI_query('SHOW FULL FIELDS FROM ' . PMA_backquote($table) . ';', null, PMA_DBI_QUERY_STORE);
-$fields_cnt  = PMA_DBI_num_rows($fields_rs);
+$fields = (array) PMA_DBI_get_columns($db, $table, null, true);
 
 // Get more complete field information
 // For now, this is done just for MySQL 4.1.2+ new TIMESTAMP options
 // but later, if the analyser returns more information, it
 // could be executed for any MySQL version and replace
-// the info given by SHOW FULL FIELDS FROM.
+// the info given by SHOW FULL COLUMNS FROM.
 //
 // We also need this to correctly learn if a TIMESTAMP is NOT NULL, since
-// SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
+// SHOW FULL COLUMNS or INFORMATION_SCHEMA incorrectly says NULL
 // and SHOW CREATE TABLE says NOT NULL (tested
 // in MySQL 4.0.25 and 5.0.21, http://bugs.mysql.com/20910).
 
@@ -147,30 +146,34 @@ $analyzed_sql = PMA_SQP_analyze(PMA_SQP_parse($show_create_table));
  */
 // action titles (image or string)
 $titles = array();
-$titles['Change']               = PMA_getIcon('b_edit.png', __('Change'), true);
-$titles['Drop']                 = PMA_getIcon('b_drop.png', __('Drop'), true);
-$titles['NoDrop']               = PMA_getIcon('b_drop.png', __('Drop'), true);
-$titles['Primary']              = PMA_getIcon('b_primary.png', __('Primary'), true);
-$titles['Index']                = PMA_getIcon('b_index.png', __('Index'), true);
-$titles['Unique']               = PMA_getIcon('b_unique.png', __('Unique'), true);
-$titles['IdxFulltext']          = PMA_getIcon('b_ftext.png', __('Fulltext'), true);
-$titles['NoPrimary']            = PMA_getIcon('bd_primary.png', __('Primary'), true);
-$titles['NoIndex']              = PMA_getIcon('bd_index.png', __('Index'), true);
-$titles['NoUnique']             = PMA_getIcon('bd_unique.png', __('Unique'), true);
-$titles['NoIdxFulltext']        = PMA_getIcon('bd_ftext.png', __('Fulltext'), true);
-$titles['BrowseDistinctValues'] = PMA_getIcon('b_browse.png', __('Browse distinct values'), true);
+$titles['Change']               = PMA_getIcon('b_edit.png', __('Change'));
+$titles['Drop']                 = PMA_getIcon('b_drop.png', __('Drop'));
+$titles['NoDrop']               = PMA_getIcon('b_drop.png', __('Drop'));
+$titles['Primary']              = PMA_getIcon('b_primary.png', __('Primary'));
+$titles['Index']                = PMA_getIcon('b_index.png', __('Index'));
+$titles['Unique']               = PMA_getIcon('b_unique.png', __('Unique'));
+$titles['Spatial']              = PMA_getIcon('b_spatial.png', __('Spatial'));
+$titles['IdxFulltext']          = PMA_getIcon('b_ftext.png', __('Fulltext'));
+$titles['NoPrimary']            = PMA_getIcon('bd_primary.png', __('Primary'));
+$titles['NoIndex']              = PMA_getIcon('bd_index.png', __('Index'));
+$titles['NoUnique']             = PMA_getIcon('bd_unique.png', __('Unique'));
+$titles['NoSpatial']            = PMA_getIcon('bd_spatial.png', __('Spatial'));
+$titles['NoIdxFulltext']        = PMA_getIcon('bd_ftext.png', __('Fulltext'));
+$titles['BrowseDistinctValues'] = PMA_getIcon('b_browse.png', __('Browse distinct values'));
 
 // hidden action titles (image and string)
 $hidden_titles = array();
-$hidden_titles['BrowseDistinctValues'] = PMA_getIcon('b_browse.png', __('Browse distinct values'), false, true);
-$hidden_titles['Primary']              = PMA_getIcon('b_primary.png', __('Add primary key'), false, true);
-$hidden_titles['NoPrimary']            = PMA_getIcon('bd_primary.png', __('Add primary key'), false, true);
-$hidden_titles['Index']                = PMA_getIcon('b_index.png', __('Add index'), false, true);
-$hidden_titles['NoIndex']              = PMA_getIcon('bd_index.png', __('Add index'), false, true);
-$hidden_titles['Unique']               = PMA_getIcon('b_unique.png', __('Add unique index'), false, true);
-$hidden_titles['NoUnique']             = PMA_getIcon('bd_unique.png', __('Add unique index'), false, true);
-$hidden_titles['IdxFulltext']          = PMA_getIcon('b_ftext.png', __('Add FULLTEXT index'), false, true);
-$hidden_titles['NoIdxFulltext']        = PMA_getIcon('bd_ftext.png', __('Add FULLTEXT index'), false, true);
+$hidden_titles['BrowseDistinctValues'] = PMA_getIcon('b_browse.png', __('Browse distinct values'), true);
+$hidden_titles['Primary']              = PMA_getIcon('b_primary.png', __('Add primary key'), true);
+$hidden_titles['NoPrimary']            = PMA_getIcon('bd_primary.png', __('Add primary key'), true);
+$hidden_titles['Index']                = PMA_getIcon('b_index.png', __('Add index'), true);
+$hidden_titles['NoIndex']              = PMA_getIcon('bd_index.png', __('Add index'), true);
+$hidden_titles['Unique']               = PMA_getIcon('b_unique.png', __('Add unique index'), true);
+$hidden_titles['NoUnique']             = PMA_getIcon('bd_unique.png', __('Add unique index'), true);
+$hidden_titles['Spatial']              = PMA_getIcon('b_spatial.png', __('Add SPATIAL index'), true);
+$hidden_titles['NoSpatial']            = PMA_getIcon('bd_spatial.png', __('Add SPATIAL index'), true);
+$hidden_titles['IdxFulltext']          = PMA_getIcon('b_ftext.png', __('Add FULLTEXT index'), true);
+$hidden_titles['NoIdxFulltext']        = PMA_getIcon('bd_ftext.png', __('Add FULLTEXT index'), true);
 
 /**
  * Displays the table structure ('show table' works correct since 3.23.03)
@@ -179,23 +182,24 @@ $hidden_titles['NoIdxFulltext']        = PMA_getIcon('bd_ftext.png', __('Add FUL
 // table header
 $i = 0;
 ?>
-<form method="post" action="tbl_structure.php" name="fieldsForm" id="fieldsForm">
+<form method="post" action="tbl_structure.php" name="fieldsForm" id="fieldsForm" <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' class="ajax"' : '');?>>
     <?php echo PMA_generate_common_hidden_inputs($db, $table);
     echo '<input type="hidden" name="table_type" value=';
-	if($db_is_information_schema) {
-	     echo '"information_schema" />';
-	} else if ($tbl_is_view) {
-	     echo '"view" />';
-	} else {
-	     echo '"table" />';
-	} ?>
+    if ($db_is_information_schema) {
+         echo '"information_schema" />';
+    } else if ($tbl_is_view) {
+         echo '"view" />';
+    } else {
+         echo '"table" />';
+    } ?>
 
-<table id="tablestructure" class="data">
+<table id="tablestructure" class="data<?php
+    if ($GLOBALS['cfg']['PropertiesIconic'] === true) echo ' PropertiesIconic'; ?>">
 <thead>
 <tr>
     <th id="th<?php echo ++$i; ?>"></th>
     <th id="th<?php echo ++$i; ?>">#</th>
-    <th id="th<?php echo ++$i; ?>" class="column"><?php echo __('Column'); ?></th>
+    <th id="th<?php echo ++$i; ?>" class="column"><?php echo __('Name'); ?></th>
     <th id="th<?php echo ++$i; ?>" class="type"><?php echo __('Type'); ?></th>
     <th id="th<?php echo ++$i; ?>" class="collation"><?php echo __('Collation'); ?></th>
     <th id="th<?php echo ++$i; ?>" class="attributes"><?php echo __('Attributes'); ?></th>
@@ -205,7 +209,16 @@ $i = 0;
 <?php if ($db_is_information_schema || $tbl_is_view) { ?>
     <th id="th<?php echo ++$i; ?>" class="view"><?php echo __('View'); ?></th>
 <?php } else { ?>
-    <th colspan="7" id="th<?php echo ++$i; ?>" class="action"><?php echo __('Action'); ?></th>
+    <th colspan="<?php
+    $colspan = 9;
+    if (PMA_DRIZZLE) {
+        $colspan -= 2;
+    }
+    if ($GLOBALS['cfg']['PropertiesIconic']) {
+        $colspan--;
+    }
+    echo $colspan; ?>"
+        id="th<?php echo ++$i; ?>" class="action"><?php echo __('Action'); ?></th>
 <?php } ?>
 </tr>
 </thead>
@@ -221,7 +234,7 @@ $comments_map = array();
 $mime_map = array();
 
 if ($GLOBALS['cfg']['ShowPropertyComments']) {
-    require_once './libraries/transformations.lib.php';
+    include_once './libraries/transformations.lib.php';
 
     //$cfgRelation = PMA_getRelationsParam();
 
@@ -237,7 +250,7 @@ $aryFields = array();
 $checked   = (!empty($checkall) ? ' checked="checked"' : '');
 $save_row  = array();
 $odd_row   = true;
-while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
+foreach ($fields as $row) {
     $save_row[] = $row;
     $rownum++;
     $aryFields[]      = $row['Field'];
@@ -246,53 +259,34 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
     $extracted_fieldspec = PMA_extractFieldSpec($row['Type']);
 
     if ('set' == $extracted_fieldspec['type'] || 'enum' == $extracted_fieldspec['type']) {
-        $type         = $extracted_fieldspec['type'] . '(' .
-            str_replace("','", "', '", $extracted_fieldspec['spec_in_brackets']) . ')';
-
-        // for the case ENUM('&#8211;','&ldquo;')
-        $type         = htmlspecialchars($type);
-        if(strlen($type) > $GLOBALS['cfg']['LimitChars']) {
-            $type = '<abbr title="' . $type . '">' . substr($type, 0, $GLOBALS['cfg']['LimitChars']) . '</abbr>';
-        }
-
         $type_nowrap  = '';
-
-        $binary       = 0;
-        $unsigned     = 0;
-        $zerofill     = 0;
     } else {
         $type_nowrap  = ' nowrap="nowrap"';
-        // strip the "BINARY" attribute, except if we find "BINARY(" because
-        // this would be a BINARY or VARBINARY field type
-        if (!preg_match('@BINARY[\(]@i', $type)) {
-            $type         = preg_replace('@BINARY@i', '', $type);
-        }
-        $type         = preg_replace('@ZEROFILL@i', '', $type);
-        $type         = preg_replace('@UNSIGNED@i', '', $type);
-        if (empty($type)) {
-            $type     = ' ';
-        }
-
-        if (!preg_match('@BINARY[\(]@i', $row['Type'])) {
-            $binary           = stristr($row['Type'], 'blob') || stristr($row['Type'], 'binary');
-        } else {
-            $binary           = false;
-        }
-
-        $unsigned     = stristr($row['Type'], 'unsigned');
-        $zerofill     = stristr($row['Type'], 'zerofill');
+    }
+    $type         = $extracted_fieldspec['print_type'];
+    if (empty($type)) {
+        $type     = ' ';
+    }
+    // for the case ENUM('&#8211;','&ldquo;')
+    $type         = htmlspecialchars($type);
+    // in case it is too long
+    $start = 0;
+    if (strlen($type) > $GLOBALS['cfg']['LimitChars']) {
+        $start = 13;
+        $type = '<abbr title="' . $type . '">' . substr($type, 0, $GLOBALS['cfg']['LimitChars']) . '</abbr>';
     }
 
     unset($field_charset);
-    if ((substr($type, 0, 4) == 'char'
-        || substr($type, 0, 7) == 'varchar'
-        || substr($type, 0, 4) == 'text'
-        || substr($type, 0, 8) == 'tinytext'
-        || substr($type, 0, 10) == 'mediumtext'
-        || substr($type, 0, 8) == 'longtext'
-        || substr($type, 0, 3) == 'set'
-        || substr($type, 0, 4) == 'enum'
-        ) && !$binary) {
+    if ((substr($type, $start, 4) == 'char'
+        || substr($type, $start, 7) == 'varchar'
+        || substr($type, $start, 4) == 'text'
+        || substr($type, $start, 8) == 'tinytext'
+        || substr($type, $start, 10) == 'mediumtext'
+        || substr($type, $start, 8) == 'longtext'
+        || substr($type, $start, 3) == 'set'
+        || substr($type, $start, 4) == 'enum')
+        && !$extracted_fieldspec['binary']
+    ) {
         if (strpos($type, ' character set ')) {
             $type = substr($type, 0, strpos($type, ' character set '));
         }
@@ -312,16 +306,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         $type_mime = '';
     }
 
-    $attribute     = ' ';
-    if ($binary) {
-        $attribute = 'BINARY';
-    }
-    if ($unsigned) {
-        $attribute = 'UNSIGNED';
-    }
-    if ($zerofill) {
-        $attribute = 'UNSIGNED ZEROFILL';
-    }
+    $attribute     = $extracted_fieldspec['attribute'];
 
     // MySQL 4.1.2+ TIMESTAMP options
     // (if on_update_current_timestamp is set, then it's TRUE)
@@ -329,7 +314,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         $attribute = 'on update CURRENT_TIMESTAMP';
     }
 
-    // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
+    // here, we have a TIMESTAMP that SHOW FULL COLUMNS reports as having the
     // NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
     // the latter.
     if (!empty($analyzed_sql[0]['create_table_fields'][$row['Field']]['type']) && $analyzed_sql[0]['create_table_fields'][$row['Field']]['type'] == 'TIMESTAMP' && $analyzed_sql[0]['create_table_fields'][$row['Field']]['timestamp_not_null']) {
@@ -337,7 +322,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
     }
 
 
-    if (!isset($row['Default'])) {
+    if (! isset($row['Default'])) {
         if ($row['Null'] == 'YES') {
             $row['Default'] = '<i>NULL</i>';
         }
@@ -380,15 +365,10 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         } else {
             echo $row['Default'];
         }
-    }
-    else {
-        echo '<i>' . _pgettext('None for default','None') . '</i>';
+    } else {
+        echo '<i>' . _pgettext('None for default', 'None') . '</i>';
     } ?></td>
     <td nowrap="nowrap"><?php echo strtoupper($row['Extra']); ?></td>
-    <td align="center" class="browse">
-        <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('SELECT COUNT(*) AS ' . PMA_backquote(__('Rows')) . ', ' . PMA_backquote($row['Field']) . ' FROM ' . PMA_backquote($table) . ' GROUP BY ' . PMA_backquote($row['Field']) . ' ORDER BY ' . PMA_backquote($row['Field'])); ?>">
-            <?php echo $titles['BrowseDistinctValues']; ?></a>
-    </td>
     <?php if (! $tbl_is_view && ! $db_is_information_schema) { ?>
     <td align="center" class="edit">
         <a href="tbl_alter.php?<?php echo $url_query; ?>&amp;field=<?php echo $field_encoded; ?>">
@@ -398,7 +378,13 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         <a <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' class="drop_column_anchor"' : ''); ?> href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' DROP ' . PMA_backquote($row['Field'])); ?>&amp;dropped_column=<?php echo urlencode($row['Field']); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('Column %s has been dropped'), htmlspecialchars($row['Field']))); ?>" >
             <?php echo $titles['Drop']; ?></a>
     </td>
-    <td align="center" class="primary">
+    <?php } ?>
+    <td align="center" class="browse replaced_by_more">
+        <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('SELECT COUNT(*) AS ' . PMA_backquote(__('Rows')) . ', ' . PMA_backquote($row['Field']) . ' FROM ' . PMA_backquote($table) . ' GROUP BY ' . PMA_backquote($row['Field']) . ' ORDER BY ' . PMA_backquote($row['Field'])); ?>">
+            <?php echo $titles['BrowseDistinctValues']; ?></a>
+    </td>
+    <?php if (! $tbl_is_view && ! $db_is_information_schema) { ?>
+    <td align="center" class="primary replaced_by_more">
         <?php
         if ($type == 'text' || $type == 'blob' || 'ARCHIVE' == $tbl_type || ($primary && $primary->hasColumn($field_name))) {
             echo $titles['NoPrimary'] . "\n";
@@ -413,7 +399,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         echo "\n";
         ?>
     </td>
-    <td align="center" class="unique">
+    <td align="center" class="unique replaced_by_more">
         <?php
         if ($type == 'text' || $type == 'blob' || 'ARCHIVE' == $tbl_type || isset($columns_with_unique_index[$field_name])) {
             echo $titles['NoUnique'] . "\n";
@@ -428,7 +414,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         echo "\n";
         ?>
     </td>
-    <td align="center" class="index">
+    <td align="center" class="index replaced_by_more">
         <?php
         if ($type == 'text' || $type == 'blob' || 'ARCHIVE' == $tbl_type) {
             echo $titles['NoIndex'] . "\n";
@@ -443,14 +429,36 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         }
         echo "\n";
         ?>
+    </td>
+        <?php
+        if (!PMA_DRIZZLE) { ?>
+    <td align="center" class="spatial replaced_by_more">
+        <?php
+        $spatial_types = array(
+            'geometry', 'point', 'linestring', 'polygon', 'multipoint',
+            'multilinestring', 'multipolygon', 'geomtrycollection'
+        );
+        if (! in_array($type, $spatial_types) || 'MYISAM' != $tbl_type) {
+            echo $titles['NoSpatial'] . "\n";
+            $spatial_enabled = false;
+        } else {
+            echo "\n";
+            ?>
+        <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD SPATIAL(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
+            <?php echo $titles['Spatial']; ?></a>
+            <?php
+            $spatial_enabled = true;
+        }
+        echo "\n";
+        ?>
     </td>
     <?php
-        if (! empty($tbl_type) && ($tbl_type == 'MYISAM' || $tbl_type == 'ARIA' || $tbl_type == 'MARIA')
+        if (! empty($tbl_type) && ($tbl_type == 'MYISAM' || $tbl_type == 'ARIA' || $tbl_type == 'MARIA' || ($tbl_type == 'INNODB' && PMA_MYSQL_INT_VERSION >= 50604))
             // FULLTEXT is possible on TEXT, CHAR and VARCHAR
             && (strpos(' ' . $type, 'text') || strpos(' ' . $type, 'char'))) {
             echo "\n";
             ?>
-    <td align="center" nowrap="nowrap" class="fulltext">
+    <td align="center" nowrap="nowrap" class="fulltext replaced_by_more">
         <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD FULLTEXT(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
             <?php echo $titles['IdxFulltext']; ?></a>
             <?php $fulltext_enabled = true; ?>
@@ -459,27 +467,28 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         } else {
             echo "\n";
         ?>
-    <td align="center" nowrap="nowrap" class="fulltext">
+    <td align="center" nowrap="nowrap" class="fulltext replaced_by_more">
         <?php echo $titles['NoIdxFulltext'] . "\n"; ?>
         <?php $fulltext_enabled = false; ?>
     </td>
         <?php
+            }
         } // end if... else...
         echo "\n";
-        ?>
+        if ($GLOBALS['cfg']['PropertiesIconic'] !== true) { ?>
     <td class="more_opts" id="more_opts<?php echo $rownum; ?>">
-        <?php echo __('More'); ?> <img src="<?php echo $pmaThemeImage . 'more.png'; ?>" alt="<?php echo __('Show more actions'); ?>" />
+        <?php echo PMA_getImage('more.png', __('Show more actions')); ?> <?php echo __('More'); ?>
         <div class="structure_actions_dropdown" id="row_<?php echo $rownum; ?>">
 
-            <div class="action_browse">
+            <div class="action_browse replace_in_more">
                 <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('SELECT COUNT(*) AS ' . PMA_backquote(__('Rows')) . ', ' . PMA_backquote($row['Field']) . ' FROM ' . PMA_backquote($table) . ' GROUP BY ' . PMA_backquote($row['Field']) . ' ORDER BY ' . PMA_backquote($row['Field'])); ?>">
                     <?php echo $hidden_titles['BrowseDistinctValues']; ?>
                 </a>
             </div>
-            <div <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' class="action_primary"' : ''); ?>>
+            <div  class="<?php echo ($GLOBALS['cfg']['AjaxEnable'] ? 'action_primary ' : ''); ?>replace_in_more">
                 <?php
-                if(isset($primary_enabled)) {
-                     if($primary_enabled) { ?>
+                if (isset($primary_enabled)) {
+                     if ($primary_enabled) { ?>
                           <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ($primary ? ' DROP PRIMARY KEY,' : '') . ' ADD PRIMARY KEY(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('A primary key has been added on %s'), htmlspecialchars($row['Field']))); ?>">
                              <?php echo $hidden_titles['Primary']; ?>
                          </a>
@@ -489,10 +498,10 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
                      }
                 } ?>
             </div>
-            <div class="action_unique">
+            <div class="action_unique replace_in_more">
                 <?php
-                if(isset($unique_enabled)) {
-                     if($unique_enabled) { ?>
+                if (isset($unique_enabled)) {
+                     if ($unique_enabled) { ?>
                          <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD UNIQUE(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
                              <?php echo $hidden_titles['Unique']; ?>
                          </a>
@@ -502,10 +511,10 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
                      }
                 } ?>
             </div>
-            <div class="action_index">
+            <div class="action_index replace_in_more">
                <?php
-                if(isset($index_enabled)) {
-                     if($index_enabled) { ?>
+                if (isset($index_enabled)) {
+                     if ($index_enabled) { ?>
                          <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD INDEX(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
                              <?php echo $hidden_titles['Index']; ?>
                          </a>
@@ -514,11 +523,25 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
                          echo $hidden_titles['NoIndex'];
                      }
                   } ?>
-             </div>
-            <div class="action_fulltext">
+            </div>
+            <?php if (!PMA_DRIZZLE) { ?>
+            <div class="action_spatial replace_in_more">
                 <?php
-                if(isset($fulltext_enabled)) {
-                     if($fulltext_enabled) { ?>
+                if (isset($spatial_enabled)) {
+                    if ($spatial_enabled) { ?>
+                        <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD SPATIAL(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
+                            <?php echo $hidden_titles['Spatial']; ?>
+                        </a>
+                    <?php
+                    } else {
+                        echo $hidden_titles['NoSpatial'];
+                    }
+                } ?>
+            </div>
+            <div class="action_fulltext replace_in_more">
+                <?php
+                if (isset($fulltext_enabled)) {
+                     if ($fulltext_enabled) { ?>
                          <a href="sql.php?<?php echo $url_query; ?>&amp;sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' ADD FULLTEXT(' . PMA_backquote($row['Field']) . ')'); ?>&amp;message_to_show=<?php echo urlencode(sprintf(__('An index has been added on %s'), htmlspecialchars($row['Field']))); ?>">
                              <?php echo $hidden_titles['IdxFulltext']; ?>
                          </a>
@@ -527,16 +550,18 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
                          echo $hidden_titles['NoIdxFulltext'];
                      }
                 } ?>
-             </div>
+            </div>
+            <?php } ?>
         </div>
     </td>
     <?php
+        } // end if (GLOBALS['cfg']['PropertiesIconic'] !== true)
     } // end if (! $tbl_is_view && ! $db_is_information_schema)
     ?>
 </tr>
     <?php
     unset($field_charset);
-} // end while
+} // end foreach
 
 echo '</tbody>' . "\n"
     .'</table>' . "\n";
@@ -568,6 +593,9 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
         PMA_buttonOrImage('submit_mult', 'mult_submit', 'submit_mult_index', __('Index'), 'b_index.png', 'index');
     }
 
+    if (! empty($tbl_type) && $tbl_type == 'MYISAM') {
+        PMA_buttonOrImage('submit_mult', 'mult_submit', 'submit_mult_spatial', __('Spatial'), 'b_spatial.png', 'spatial');
+    }
     if (! empty($tbl_type) && ($tbl_type == 'MYISAM' || $tbl_type == 'ARIA' || $tbl_type == 'MARIA')) {
         PMA_buttonOrImage('submit_mult', 'mult_submit', 'submit_mult_fulltext', __('Fulltext'), 'b_ftext.png', 'ftext');
     }
@@ -580,12 +608,25 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
 /**
  * Work on the table
  */
-?>
-<a href="tbl_printview.php?<?php echo $url_query; ?>"><?php
-if ($cfg['PropertiesIconic']) {
-    echo '<img class="icon" src="' . $pmaThemeImage . 'b_print.png" width="16" height="16" alt="' . __('Print view') . '"/>';
+
+if ($tbl_is_view) {
+    $create_view = PMA_DBI_get_definition($db, 'VIEW', $table);
+    $create_view = preg_replace('@^CREATE@', 'ALTER', $create_view);
+    echo PMA_linkOrButton(
+        'tbl_sql.php' . PMA_generate_common_url(
+            $url_params +
+            array(
+                'sql_query' => $create_view,
+                'show_query' => '1',
+            )
+        ),
+        PMA_getIcon('b_edit.png', __('Edit view'), true)
+        );
 }
-echo __('Print view');
+?>
+
+<a href="tbl_printview.php?<?php echo $url_query; ?>"><?php
+echo PMA_getIcon('b_print.png', __('Print view'), true);
 ?></a>
 
 <?php
@@ -596,42 +637,33 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
     if ($cfgRelation['relwork'] || PMA_foreignkey_supported($tbl_type)) {
         ?>
 <a href="tbl_relation.php?<?php echo $url_query; ?>"><?php
-        if ($cfg['PropertiesIconic']) {
-            echo '<img class="icon" src="' . $pmaThemeImage . 'b_relations.png" width="16" height="16" alt="' . __('Relation view') . '"/>';
-        }
-        echo __('Relation view');
+        echo PMA_getIcon('b_relations.png', __('Relation view'), true);
         ?></a>
         <?php
     }
-    ?>
+
+    if (!PMA_DRIZZLE) {
+        ?>
 <a href="sql.php?<?php echo $url_query; ?>&amp;session_max_rows=all&amp;sql_query=<?php echo urlencode('SELECT * FROM ' . PMA_backquote($table) . ' PROCEDURE ANALYSE()'); ?>"><?php
-    if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_tblanalyse.png" width="16" height="16" alt="' . __('Propose table structure') . '" />';
+        echo PMA_getIcon('b_tblanalyse.png', __('Propose table structure'), true);
+        ?></a><?php
+        echo PMA_showMySQLDocu('Extending_MySQL', 'procedure_analyse') . "\n";
     }
-    echo __('Propose table structure');
-    ?></a><?php
-    echo PMA_showMySQLDocu('Extending_MySQL', 'procedure_analyse') . "\n";
 
-
-    if(PMA_Tracker::isActive())
-    {
+    if (PMA_Tracker::isActive()) {
         echo '<a href="tbl_tracking.php?' . $url_query . '">';
-
-        if ($cfg['PropertiesIconic'])
-        {
-            echo '<img class="icon" src="' . $pmaThemeImage . 'eye.png" width="16" height="16" alt="' . __('Track table') . '" /> ';
-        }
-        echo __('Track table') . '</a>';
+        echo PMA_getIcon('eye.png', __('Track table'), true);
+        echo '</a>';
     }
     ?>
 
     <br />
-<form method="post" action="tbl_addfield.php"
+<form method="post" action="tbl_addfield.php" id="addColumns" name="addColumns" <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' class="ajax"' : '');?>
     onsubmit="return checkFormElementInRange(this, 'num_fields', '<?php echo str_replace('\'', '\\\'', __('You have to add at least one column.')); ?>', 1)">
     <?php
     echo PMA_generate_common_hidden_inputs($db, $table);
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_insrow.png" width="16" height="16" alt="' . __('Add column') . '"/>';
+        echo PMA_getImage('b_insrow.png', __('Add column'));
     }
     echo sprintf(__('Add %s column(s)'), '<input type="text" name="num_fields" size="2" maxlength="2" value="1" onfocus="this.select()" />');
 
@@ -657,6 +689,7 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
 </form>
 <iframe class="IE_hack" scrolling="no"></iframe>
 <hr />
+<div id="index_div" <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' class="ajax"' : ''); ?> >
     <?php
 }
 
@@ -664,35 +697,34 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
  * If there are more than 20 rows, displays browse/select/insert/empty/drop
  * links again
  */
-if ($fields_cnt > 20) {
-    require './libraries/tbl_links.inc.php';
-} // end if ($fields_cnt > 20)
+if (count($fields) > 20) {
+    include './libraries/tbl_links.inc.php';
+} // end if (count($fields) > 20)
 
 /**
  * Displays indexes
  */
 
 if (! $tbl_is_view && ! $db_is_information_schema && 'ARCHIVE' !=  $tbl_type) {
+    PMA_generate_slider_effect('indexes', __('Indexes'));
     /**
      * Display indexes
      */
     echo PMA_Index::getView($table, $db);
     ?>
-<br />
-<form action="./tbl_indexes.php" method="post"
-    onsubmit="return checkFormElementInRange(this, 'added_fields',
-        '<?php echo str_replace('\'', '\\\'', __('Column count has to be larger than zero.')); ?>',
-        1)">
-<fieldset>
-    <?php
-    echo PMA_generate_common_hidden_inputs($db, $table);
-    echo sprintf(__('Create an index on &nbsp;%s&nbsp;columns'),
-        '<input type="text" size="2" name="added_fields" value="1" />');
-    ?>
-    <input type="submit" name="create_index" value="<?php echo __('Go'); ?>" />
-</fieldset>
-</form>
-<br />
+        <fieldset class="tblFooters" style="text-align: left;">
+            <form action="./tbl_indexes.php" method="post">
+                <?php
+                echo PMA_generate_common_hidden_inputs($db, $table);
+                echo sprintf(__('Create an index on &nbsp;%s&nbsp;columns'),
+                    '<input type="text" size="2" name="added_fields" value="1" />');
+                ?>
+                <input type="hidden" name="create_index" value="1" />
+                <input class="add_index<?php echo ($GLOBALS['cfg']['AjaxEnable'] ? ' ajax' : '');?>" type="submit" value="<?php echo __('Go'); ?>" />
+            </form>
+        </fieldset>
+    </div>
+</div>
     <?php
 }
 
@@ -718,7 +750,7 @@ if ($cfg['ShowStats']) {
     $mergetable = PMA_Table::isMerge($GLOBALS['db'], $GLOBALS['table']);
 
     // this is to display for example 261.2 MiB instead of 268k KiB
-    $max_digits = 5;
+    $max_digits = 3;
     $decimals = 1;
     list($data_size, $data_unit)         = PMA_formatByteDown($showtable['Data_length'], $max_digits, $decimals);
     if ($mergetable == false) {
@@ -740,16 +772,12 @@ if ($cfg['ShowStats']) {
     $odd_row = false;
     ?>
 
+    <fieldset>
+    <legend><?php echo __('Information'); ?></legend>
     <a name="showusage"></a>
     <?php if (! $tbl_is_view && ! $db_is_information_schema) { ?>
     <table id="tablespaceusage" class="data">
     <caption class="tblHeaders"><?php echo __('Space usage'); ?></caption>
-    <thead>
-    <tr>
-        <th><?php echo __('Type'); ?></th>
-        <th colspan="2"><?php echo __('Usage'); ?></th>
-    </tr>
-    </thead>
     <tbody>
     <tr class="<?php echo ($odd_row = !$odd_row) ? 'odd' : 'even'; ?>">
         <th class="name"><?php echo __('Data'); ?></th>
@@ -790,15 +818,12 @@ if ($cfg['ShowStats']) {
             <?php
         }
         // Optimize link if overhead
-        if (isset($free_size) && ($tbl_type == 'MYISAM' || $tbl_type == 'ARIA' || $tbl_type == 'MARIA' || $tbl_type == 'BDB')) {
+        if (isset($free_size) && !PMA_DRIZZLE && ($tbl_type == 'MYISAM' || $tbl_type == 'ARIA' || $tbl_type == 'MARIA' || $tbl_type == 'BDB')) {
             ?>
     <tr class="tblFooters">
         <td colspan="3" align="center">
             <a href="sql.php?<?php echo $url_query; ?>&pos=0&amp;sql_query=<?php echo urlencode('OPTIMIZE TABLE ' . PMA_backquote($table)); ?>"><?php
-            if ($cfg['PropertiesIconic']) {
-               echo '<img class="icon" src="' . $pmaThemeImage . 'b_tbloptimize.png" width="16" height="16" alt="' . __('Optimize table'). '" />';
-            }
-            echo __('Optimize table');
+            echo PMA_getIcon('b_tbloptimize.png', __('Optimize table'));
             ?></a>
         </td>
     </tr>
@@ -813,12 +838,6 @@ if ($cfg['ShowStats']) {
     ?>
     <table id="tablerowstats" class="data">
     <caption class="tblHeaders"><?php echo __('Row Statistics'); ?></caption>
-    <thead>
-    <tr>
-        <th><?php echo __('Statements'); ?></th>
-        <th><?php echo __('Value'); ?></th>
-    </tr>
-    </thead>
     <tbody>
     <?php
     if (isset($showtable['Row_format'])) {
@@ -880,7 +899,7 @@ if ($cfg['ShowStats']) {
     if (!$is_innodb && isset($showtable['Data_length']) && $showtable['Rows'] > 0 && $mergetable == false) {
         ?>
     <tr class="<?php echo ($odd_row = !$odd_row) ? 'odd' : 'even'; ?>">
-        <th class="name"><?php echo __(' Row size '); ?> &oslash;</th>
+        <th class="name"><?php echo __('Row size'); ?> &oslash;</th>
         <td class="value"><?php echo $avg_size . ' ' . $avg_unit; ?></td>
     </tr>
         <?php
@@ -888,7 +907,7 @@ if ($cfg['ShowStats']) {
     if (isset($showtable['Auto_increment'])) {
         ?>
     <tr class="<?php echo ($odd_row = !$odd_row) ? 'odd' : 'even'; ?>">
-        <th class="name"><?php echo __('Next'); ?> Autoindex</th>
+        <th class="name"><?php echo __('Next autoindex'); ?></th>
         <td class="value"><?php echo PMA_formatNumber($showtable['Auto_increment'], 0); ?></td>
     </tr>
         <?php
@@ -920,7 +939,7 @@ if ($cfg['ShowStats']) {
     ?>
     </tbody>
     </table>
-
+    </fieldset>
     <!-- close tablestatistics div -->
     </div>
 
@@ -928,8 +947,6 @@ if ($cfg['ShowStats']) {
 }
 // END - Calc Table Space
 
-require './libraries/tbl_triggers.lib.php';
-
 echo '<div class="clearfloat"></div>' . "\n";
 
 /**
